@@ -126,6 +126,8 @@ int game_run()
 		OAMData[loop] = temp[loop];
 	}
 	
+	sfxSystemInit();
+	
 	g.ship = playership_new();
 	g.num_aliens = aliens_per_wave * waves;
 	g.aliens = calloc(g.num_aliens, sizeof(alien));
@@ -138,9 +140,10 @@ int game_run()
 	{
 		channels[i] = sfxSystemAllocChannel();
 	}
-	m.master_volume = 12;
+	m.master_volume = 10;
+	m.pattern = 0;
+	m.line = 0;
 
-	sfxSystemInit();
 
 	/* main game loop */
 	while(!die)
@@ -160,7 +163,7 @@ int game_run()
 			}
 
 			wave_timer = wave_length;
-			if(wave_length > 35) wave_length -= 5;
+			if(wave_length > 50) wave_length = (wave_length * FIXED_INT(0.95)) >> 8;
 
 			wave++;
 			if(wave == waves) wave = 0;
