@@ -11,13 +11,16 @@ void print(char *s)
 		
 }
 
+mod_header m;
+
 ///main entry point from the boot.asm startup file
 int AgbMain()
 {
 	interrupt_init();
-	init_sfx_system();
 	InitialiseSprites();
 	
+	mod_parse(&m, foo_mod);
+
 	while(1)
 	{
 		intro();
