@@ -29,6 +29,9 @@ playership* playership_new()
 	s->sprite.tile = (4*2) * PLAYERSHIP_FRAME_NORMAL;
 	s->sprite.sprite = sprite_alloc();
 
+	/* allocate a sound channel for bullets */
+	s->bullet_channel = sfxSystemAllocChannel();
+
 	/* create bullets */
 	s->num_bullets = PLAYERSHIP_NUM_BULLETS;
 	s->bullets = malloc(sizeof(bullet) * s->num_bullets);
@@ -103,7 +106,7 @@ void playership_read_keys(playership* ship, u32 keys)
 					b->speed = BULLET_SPEED;
 					b->sprite.sprite = sprite_alloc();
 
-					sfxSystemPlay(&laser_sample);
+					sfxSystemSetChannel(ship->bullet_channel, &laser_sample);
 					/* set fire delay, and break out of bullet-finding loop */
 					ship->fire_delay = PLAYERSHIP_FIRE_DELAY;
 					break;
